var music = document.getElementById("bgMusic");
var fxclick = document.getElementById("fxclick");
var fxbutton = document.getElementById("fxbutton");

var app = {
	// records from online games (not local)
	onlineRecords: {
		"history": 0,
		"politics": 0,
		"society": 0,
		"geography": 0,
		"sports": 0,
		"language": 0
	},
	// local records from user
	userRecords: {
		"history": { "total":0, "correct":0, "points":0 },
		"politics": { "total":0, "correct":0, "points":0 },
		"society": { "total":0, "correct":0, "points":0 },
		"geography": { "total":0, "correct":0, "points":0 },
		"sports": { "total":0, "correct":0, "points":0 },
		"language": { "total":0, "correct":0, "points":0 },
		"user": { "max": 0 }
	},
	// variables needed for current game
	currentGame: {
		page: "menu",
		animation: false,
		validLanguages: ["en","es"],
		step: 0,
		topic: -1,
		letter: "",
		skips: 0,
		number: 0,
		answers: [],
		prevCategories: [],
		categories: [],
		timers:[],
		media: null,
		timerCounter: 1000,
		timerSeconds: 90000 //90000 // it should be 90000 for 90 seconds
	},
	// Variables that need to be stored from session to session
	gameOptions : {
		language: "es",
		sound: false,
		fx: false,
		night: false,
		totalGames: 0,
		totalPoints: 0,
		maxPoints: -999,
		minPoints: 999,
		averagePoints: -999,
		maxOnlinePoints: -999
	},
	// function that will be called at the begining of it all
    initialize: function() {
		// bind the events
        this.bindEvents();
		
		var listOfCategories = [];
		for (var x = 0; x < app.currentGame.categories.length; x++) {
			listOfCategories.push(app.currentGame.categories[x].name);
		}
		listOfCategories.sort();
		//d3.select("#category-list").data(listOfCategories).append("li").enter().text(function(d) { return d; });
		var item = d3.select('#category-list')
						.selectAll('li')
						.data(listOfCategories).enter()
			.append('li')
			.attr('class', 'item')
			.text(function(d) { return d });
		
		app.changeView("menu");
    },
	// event binding
    bindEvents: function() {
		// different app events
        document.addEventListener('deviceready', this.onDeviceReady, false);
		document.addEventListener("backbutton", app.onBackButton, false);
		document.addEventListener("pause", app.onPause, false);
		document.addEventListener("resume", app.onResume, false);
		
		// load settings and proceed with resetting values
		app.loadSettings();
		
		app.currentGame.categories = categories_es;
		
		document.querySelector("body").setAttribute("lang", app.gameOptions.language);
		
		app.loadOnlineRecords();
		
		app.changeLanguage( app.gameOptions.language );
		if (app.gameOptions.sound) { 
			d3.select("#music").classed("off", false).classed("on", true);
			music.play(); 
		}
		if (app.gameOptions.fx) {
			d3.select("#sound").classed("off", false).classed("on", true);
		}
		if (app.gameOptions.night) {
			d3.select("#night").classed("off", false).classed("on", true);
			d3.select("html").classed("night-mode", true);
			document.getElementById("top-logo").src = "./img/logo-text-night.svg";
		}
		
		// html elements events
		var buttons = document.querySelectorAll(".button.options:not(.play):not(.star)");
		for (var x = 0; x < buttons.length; x++) {
			buttons[x].addEventListener("click", function() {
				app.changeView(this.dataset.action);
				if (app.gameOptions.fx) { fxbutton.play(); }
			});
		}
		
		document.querySelector(".button.options.star").addEventListener("click", function() {
			document.getElementById("scrim-star").className = "scrim confirm active";
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.querySelector(".button.options.play").addEventListener("click", function() {
			app.changeView("counter");
			if (app.gameOptions.fx) { fxbutton.play(); }
			try { cordova.plugins.Keyboard.disableScroll(true); } catch(e) {}
			d3.select("#counter0").style("display", "block").transition().delay(app.currentGame.timerCounter).duration(1).style("display", "none").on("end", function() {
				d3.select("#counter1").style("display", "block").transition().delay(app.currentGame.timerCounter).duration(1).style("display", "none").on("end", function() {
					d3.select("#counter2").style("display", "block").transition().delay(app.currentGame.timerCounter).duration(1).style("display", "none").on("end", function() {
						app.changeView("game");
						d3.select("#timeline").style("background-color", "#92d64d").style("width", "100%")
						                      .transition().ease(function(t){return +t}).duration(app.currentGame.timerSeconds/2).style("width", (window.innerWidth / 2) + "px").style("background-color","#ffc338")
						                      .transition().ease(function(t){return +t}).duration(app.currentGame.timerSeconds/2).style("width", "0px").style("background-color","#db5d4d")
											  .on("end", function() {
												  app.changeView("results");
												  app.writeResults();
											  });
					});
				});
			});
		});
		
		var backButtons = document.querySelectorAll(".back-button");
		for(var x = 0; x < backButtons.length; x++) {
			backButtons[x].addEventListener("click", function() {
				app.changeView("menu");
				if (app.gameOptions.fx) { fxbutton.play(); }
			});
		}
		
		var flags = document.querySelectorAll(".flag");
		for(var x = 0; x < flags.length; x++) {
			flags[x].addEventListener("click", function() {
				app.changeLanguage(this.id.replace("flag_", ""));
				if (app.gameOptions.fx) { fxbutton.play(); }
			});
		}
		
		document.getElementById("music").addEventListener("click", function() {
			if (d3.select("#music").classed("on")) {
				d3.select("#music").classed("on", false);
				app.gameOptions.sound = false;
				music.pause();
			} else {
				d3.select("#music").classed("on", true);
				app.gameOptions.sound = true;
				music.play();
			}
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.getElementById("sound").addEventListener("click", function() {
			if (d3.select("#sound").classed("on")) {
				d3.select("#sound").classed("on", false);
				app.gameOptions.fx = false;
			} else {
				d3.select("#sound").classed("on", true);
				app.gameOptions.fx = true;
			}
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.getElementById("night").addEventListener("click", function() {
			app.changeNightMode();
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.getElementById("button-reset-text").addEventListener("click", function() {
			document.getElementById("scrim-confirm").className = "scrim confirm active";
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		var scrims = document.querySelectorAll(".scrim");
		for (var x = 0; x < scrims.length; x++) {
			scrims[x].addEventListener("click", function() {
				this.className = "scrim confirm";
			});
		}
		
		document.querySelector("#scrim-confirm .yes").addEventListener("click", function() {
			app.confirmReset();
			document.getElementById("scrim-confirm").className = "scrim confirm";
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.querySelector("#scrim-gameclose .yes").addEventListener("click", function() {
			app.changeView("menu");
			document.getElementById("scrim-gameclose").className = "scrim confirm";
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.querySelector("#scrim-confirm .no").addEventListener("click", function() {
			document.querySelector(".scrim.active").className = "scrim confirm";
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.querySelector("#scrim-gameclose .no").addEventListener("click", function() {
			document.querySelector(".scrim.active").className = "scrim confirm";
			if (app.gameOptions.fx) { fxbutton.play(); }
		});
		
		document.getElementById("textbox-text").addEventListener("keyup", function(e) {
			if (e.keyCode == 13) {
				try {
					document.getElementById("textbox-text").click();
					document.getElementById("textbox-text").focus();
					if (cordova.plugins.Keyboard) { cordova.plugins.Keyboard.show(); }
				} catch(e) {}
			}
		});
		
		document.getElementById("form").addEventListener("submit", function(e) {
			e.preventDefault();
			e.stopPropagation();
			try {
				document.getElementById("textbox-text").click();
				document.getElementById("textbox-text").focus();
				if (cordova.plugins.Keyboard) { cordova.plugins.Keyboard.show(); }
			} catch(e) {}
			
			if (document.getElementById("textbox-text").value.length > 0) {
				app.newAnswer();
			} else {
				app.skipValue();
			}
			
			if (app.gameOptions.fx) { fxclick.play(); }
		});
		
		document.querySelector("#scrim-star a").addEventListener("click", function(e) {
			e.preventDefault();
			navigator.app.loadUrl('market://details?id=com.studiokah.noventasegundos', { openExternal:true });
			return false;
		});
		
		document.querySelector("#link-to-original").addEventListener("click", function(e) {
			e.preventDefault();
			navigator.app.loadUrl('market://details?id=com.alvaromontoro.ninetyseconds', { openExternal:true });
			return false;
		});
		
    },
	changeNightMode: function() {
		if (d3.select("#night").classed("on")) {
			d3.select("#night").classed("on", false);
			app.gameOptions.night = false;
			d3.select("html").classed("night-mode", false);
			document.getElementById("top-logo").src = "./img/logo-text.svg";
		} else {
			d3.select("#night").classed("on", true);
			app.gameOptions.night = true;
			d3.select("html").classed("night-mode", true);
			document.getElementById("top-logo").src = "./img/logo-text-night.svg";
		}
	},
	confirmReset: function() {
		app.userRecords = {
			"history": { "total":0, "correct":0, "points":0 },
			"politics": { "total":0, "correct":0, "points":0 },
			"society": { "total":0, "correct":0, "points":0 },
			"geography": { "total":0, "correct":0, "points":0 },
			"sports": { "total":0, "correct":0, "points":0 },
			"language": { "total":0, "correct":0, "points":0 },
			"user": { "max": 0 }
		};
		app.saveSettings();
		app.updateScores();
		app.loadOnlineRecords();
	},
	saveSettings: function() {
		storage.save("settingsES", app.gameOptions);
		storage.save("onlineRecordsES", app.onlineRecords);
		storage.save("userRecordsES", app.userRecords);
	},
	loadSettings: function() {
		var aux = storage.load("settingsES");
		if (aux != false) { 
			app.gameOptions = aux; 
		} else { 
			storage.save("settingsES", app.gameOptions ); 
		}
		
		aux = storage.load("onlineRecordsES");
		if (aux != false) { 
			app.onlineRecords = aux; 
		} else {	
			storage.save("onlineRecordsES", app.onlineRecords);
		}
		
		aux = storage.load("userRecordsES");
		if (aux != false) { 
			app.userRecords = aux; 
		} else {
			storage.save("userRecordsES", app.userRecords);
		}
	},
	changeLanguage: function(newLang) {
		var validLanguages = ["en", "es"];
		if (validLanguages.indexOf(newLang) >= 0) {
			d3.select(".flag.active").classed("active", false);
			d3.select(".flag_" + newLang).classed("active", true);
			app.gameOptions.language = newLang;
			document.querySelector("body").setAttribute("lang", newLang);
		}
	},
	updateScores: function(lang) {
		var lang = lang || "es";
		var modifier   = 14/23;
		var pb = 175 + modifier * 175;
		var mb = 175 - modifier * 175;
		
		var politique  = app.userRecords.politics.total  == 0 ? 0 : (app.userRecords.politics.correct  / app.userRecords.politics.total);
		var societe    = app.userRecords.society.total   == 0 ? 0 : (app.userRecords.society.correct   / app.userRecords.society.total);
		var sports     = app.userRecords.sports.total    == 0 ? 0 : (app.userRecords.sports.correct    / app.userRecords.sports.total);
		var geographie = app.userRecords.geography.total == 0 ? 0 : (app.userRecords.geography.correct / app.userRecords.geography.total);
		var histoire   = app.userRecords.history.total   == 0 ? 0 : (app.userRecords.history.correct   / app.userRecords.history.total);
		var langue     = app.userRecords.language.total  == 0 ? 0 : (app.userRecords.language.correct  / app.userRecords.language.total);
		
		var points = [];
		points.push([175, (175 - 120 * geographie )]);
		points.push([(175 + 115 * histoire), (-modifier * (175 + 115 * histoire) + pb)]);
		points.push([(175 + 115 * langue),  ( modifier * (175 + 115 * langue ) + mb)]);
		points.push([175, (175 + 120 * politique)]);
		points.push([(175 - 115 * societe), ( modifier * (175 + 115 * societe) + mb)]);
		points.push([(175 - 115 * sports),   (-modifier * (175 + 115 * sports)   + pb)]);
		
		d3.select("#path-highscore").attr("d", "M " + points.join(" ") + " Z");
		
		d3.select("#point-geographie").attr("cx", points[0][0]).attr("cy", points[0][1]);
		d3.select("#point-histoire").attr("cx", points[1][0]).attr("cy", points[1][1]);
		d3.select("#point-langue").attr("cx", points[2][0]).attr("cy", points[2][1]);
		d3.select("#point-politique").attr("cx", points[3][0]).attr("cy", points[3][1]);
		d3.select("#point-societe").attr("cx", points[4][0]).attr("cy", points[4][1]);
		d3.select("#point-sports").attr("cx", points[5][0]).attr("cy", points[5][1]);
		
		d3.select("#percent-geographie").text(Math.round(geographie * 100) + "%");
		d3.select("#percent-histoire").text(Math.round(histoire * 100) + "%");
		d3.select("#percent-langue").text(Math.round(langue * 100) + "%");
		d3.select("#percent-politique").text(Math.round(politique * 100) + "%");
		d3.select("#percent-societe").text(Math.round(societe * 100) + "%");
		d3.select("#percent-sports").text(Math.round(sports * 100) + "%");
		
	},
	// load the records from the server
	loadOnlineRecords: function() {
		/*d3.json(
			"http://studiokah.com/services/nseconds/new-index?action=get_points&source=android",
			function(d) {
				if (d.valid) {
					app.onlineRecords = d.values;
					app.saveSettings();
					app.updateScores();
				}
			}
		);*/
		app.updateScores();
	},
	// actions to be taken when the device is ready
    onDeviceReady: function() {
        ads.loadBanner();
    },
	// actions to be taken when the back button is pressed
	onBackButton: function() {
		switch(app.currentGame.page) {
			case "counter":
				break;
			case "game":
				document.getElementById("scrim-gameclose").className = "scrim confirm active";
				break;
			case "menu":
				// user is in the main menu, exit the app
				music.pause();
				navigator.app.exitApp();
				break;
			default:
				app.changeView("menu");
				break;
		}
	},
	// actions to be taken when the game goes to a background mode
	onPause: function() {
		// pause the music
		music.pause();
		
		// if during the game: stop animation and go to main menu
		if (app.currentGame.page == "game") {
			d3.select("#timeline").transition().duration(0);
			app.changeView("menu");
			// hide the keyboard
            try { cordova.plugins.Keyboard.close(); cordova.plugins.Keyboard.disableScroll(false); } catch(e) {}
		}
	},
	// actions to be taken when the game resumes
	onResume: function() {
		// hide the keyboard
        try { cordova.plugins.Keyboard.close(); cordova.plugins.Keyboard.disableScroll(false); } catch(e) {}
		// restart the music if it's in the options
		if (app.gameOptions.sound) { music.play(); }
	},
	// change the current view
	changeView: function(id) {
		switch(app.currentGame.page) {
			case "settings":
				app.saveSettings();
				break;
			case "game":
				d3.select("#timeline").transition().duration(0);
				break;
			case "results":
				for (var x = 0; x < app.currentGame.timers.length; x++) {
					clearTimeout(app.currentGame.timers[x]);
				}
				app.currentGame.timers = [];
				break;
		}
		
		app.currentGame.page = id;
		
		document.querySelector(".viewframe.active").className = "viewframe";
		ads.hideBanner();
		document.getElementById(id).className = "viewframe active";
		
		switch(id) {
			// show ad for highscores and results views
			case "menu":
				ads.loadInterstitial();
				break;
			case "highscores":
				ads.showBanner();
				break;
			case "results":
				try { cordova.plugins.Keyboard.close(); cordova.plugins.Keyboard.disableScroll(false); } catch(e) {}
				ads.showInterstitial();
				ads.showBanner();
				break;
			// start game play if we are in the game view
			case "game":
				//cordova.plugins.Keyboard.disableScroll(false);
				app.initializeGame();
				try {
					document.getElementById("textbox-text").click();
					document.getElementById("textbox-text").focus();
					if (cordova.plugins.Keyboard) { cordova.plugins.Keyboard.show(); }
				} catch(e) {}
				break;
		}
	},
	initializeGame: function() {
		// reset game variables
		//app.currentGame.prevCategories = [];
		app.currentGame.answers = [];
		app.currentGame.step = 0;
		app.currentGame.topic = -1;
		app.currentGame.letter = "";
		app.currentGame.skips = 0;
		app.currentGame.number = 0;
		
		// set the field as blank
		document.getElementById("textbox-text").value = "";
		
		app.generateRound();
	},
	generateRound: function() {
		var attempts = 0;
		var randLevel, randWord;
		
		do {
			// select a random word within a random topic
			randLevel = Math.floor(Math.random() * app.currentGame.categories.length);
			randWord  = Math.floor(Math.random() * app.currentGame.categories[randLevel].values.length);
			
			// initialize the values for this round
			app.currentGame.letter = app.currentGame.categories[randLevel].values[randWord].toLowerCase().charAt(0);
			app.currentGame.topic  = randLevel;
			attempts++;
		} while(attempts < 20 && app.currentGame.prevCategories.indexOf(app.currentGame.letter + app.currentGame.topic) >= 0)
			
		// add the letter-topic combination to the previous array to avoid it being repeated
		// limit the array size to 50 elements to avoid memory problems
		app.currentGame.prevCategories.push(app.currentGame.letter + app.currentGame.topic);
		if (app.currentGame.prevCategories.length > 50) { app.currentGame.prevCategories.shift(); }
		
		app.currentGame.number++;
		
		// display the changes on the screen
		document.getElementById("textbox-text").value = "";
		document.getElementById("category-text").innerHTML = app.currentGame.categories[app.currentGame.topic].name;
		document.getElementById("letter-text").innerHTML = app.currentGame.letter.toLowerCase().latinize().toLowerCase();
	},
	newAnswer: function() {
		// add the letter if it was not written already
		var aux = document.getElementById("textbox-text").value;
		//if (aux.length > 0 && aux[0].latinize() != app.currentGame.letter.latinize()) { aux = app.currentGame.letter.latinize() + aux; }
		
		// if we are in the game, save the answer
		if (app.currentGame.step == 0) {
			app.currentGame.answers.push({
				"topic" : app.currentGame.topic,
				"letter": app.currentGame.letter,
				"answer": aux
			});
		}
			
		// generate a new round of question
		app.generateRound();
	},
	skipValue: function() {
		// add a skip, and count it as a new answer
		app.currentGame.skips++;
		document.getElementById("textbox-text").value = "";
		app.newAnswer();
	},
	checkWord: function(word, topic, letter) {
		var difference = 100;
		var position = -1;
		var x = 0;
		var found = false;
		var returnWord = "";
		
		word = word.latinize();
		
		for (var y = 0; y <app.currentGame.categories[topic].type.length; y++) {
			app.userRecords[ app.currentGame.categories[topic].type[y] ].total++;
		}
		
		// if the word is empty, return 0 points (this case should not happen in theory, but just in case)
		if (word.length < 1) { 
			while (x < app.currentGame.categories[topic].values.length && !found) {
				if (app.currentGame.categories[topic].values[x].charAt(0).toLowerCase() == letter) {
					found = true;
				}
				x++;
			}
			return { points:0, word: app.currentGame.categories[topic].values[x-1] }; 
		}
		
		found = false;
		// traverse the category comparing the words to the words in that category
		while (x < app.currentGame.categories[topic].values.length && !found) {
			if (returnWord == "" && app.currentGame.categories[topic].values[x].charAt(0).toLowerCase().latinize() == letter) { returnWord = app.currentGame.categories[topic].values[x]; }
			
			// calculate the difference between the word and the current category word (we are looking for the lowest one)
			var aux = fuzzySearch(word.toLowerCase(), app.currentGame.categories[topic].values[x].latinize().toLowerCase());
			var tdw = word.length/1 + app.currentGame.categories[topic].values[x].length/1;
			var dif = Math.round(aux.distance * 100 / tdw);
			// if the difference is lower, save the new position
			if (dif <= difference) {
				difference = dif;
				position = x;
			}
			
			// advance to the next category word if not found
			if (dif/1 == 0 && (word.length/1 < app.currentGame.categories[topic].values[x].length/1 + 2 || word.length/1 + 2 > app.currentGame.categories[topic].values[x].length/1) && letter.latinize().toLowerCase() == app.currentGame.categories[topic].values[x].toLowerCase().charAt(0).latinize().toLowerCase()) { 
				found = true; 
			} else { 
				x++; 
			}
		}
		
		// if the difference between the entered word and the category word is less than 15% (taking into consideration size also) and they start with the same letter: MATCH!
		if (difference < 15 && (word.length/1 < app.currentGame.categories[topic].values[position].length/1 + 2 || word.length/1 + 2 > app.currentGame.categories[topic].values[position].length/1) && letter.latinize().toLowerCase() == app.currentGame.categories[topic].values[position].toLowerCase().charAt(0).latinize().toLowerCase()) {
				
			// get the number of words in that category
			var sizeArray = app.currentGame.categories[topic].values.length;
			var returnPoints = 0;
				
			// words are sorted by difficulty (easy -> difficult):
			//   - if the word is in the first half: 1 point
			//   - if the word is 50-85 percentile:  2 points
			//   - if the word is top 85 percentile: 3 points
			if (position <= sizeArray * 0.5) {
				returnPoints = 1;
			} else if (position <= sizeArray * 0.85) {
				returnPoints = 2;
			} else {
				returnPoints = 3;
			}
			
			for (var y = 0; y <app.currentGame.categories[topic].type.length; y++) {
				app.userRecords[ app.currentGame.categories[topic].type[y] ].correct++;
				app.userRecords[ app.currentGame.categories[topic].type[y] ].points += returnPoints;
			}
			
			return { points:returnPoints, word:returnWord };
				
		} else {
			// not close match found: 0 points
			return { points:0, word:returnWord }
		}
	},
	writeWordBox: function(type, points, letter, word, suggestedWord, category, order) {
		
		var box = d3.select("#wordboxes")
		            .insert("div", ":first-child")
					.classed("wordbox", true)
					.classed(type, true)
					.style("animation-delay", (order/2) + "s")
					.style("-webkit-animation-delay", (order/2) + "s");
		
		if (type != "special") {
			box.append("div")
			   .classed("wordbox-letter", true)
			   .text(letter);
			box.append("div")
			   .classed("wordbox-points", true)
			   .attr("data-right", points)
			   .text(points);
			box.append("div")
			   .classed("wordbox-word", true)
			   .text(word);
			box.append("div")
			   .classed("wordbox-suggestion", true)
			   .text(suggestedWord);
			box.append("div")
			   .classed("wordbox-category", true)
			   .text(category);
			box.append("div")
			   .classed("wordbox-lightbulb", true);
			   
			if (type != "ok") {
				box.on("click", function() { box.classed("suggestion", ! box.classed("suggestion")) });
			}
		} else {
			box.append("div")
			   .classed("message", true)
			   .attr("data-points", points);
		}
		
		
	},
	writeResults: function() {
		
		var totalboxes = 0;
		var text = "";
		var good = 0;
		var skips = 0;
		var consecutive = 0;
		var arrayElementsNew = [];
		var totalPoints = 0;
		
		// clear and hide the results
		var wordboxes = document.getElementById("wordboxes");
		wordboxes.innerHTML = "";
		
		for (x = 0; x < app.currentGame.answers.length; x++) {
			
			var aux = app.checkWord(app.currentGame.answers[x].answer.toLowerCase(), app.currentGame.answers[x].topic, app.currentGame.answers[x].letter.latinize().toLowerCase());
			
			if (app.currentGame.answers[x].answer != "") {
				
				if (aux.points > 0) {
					good++;
					consecutive++;
					//app.currentGame.timers.push ( setTimeout("app.writeWordBox('ok','" + aux.points + "','" + app.currentGame.answers[x].letter + "','" + app.currentGame.answers[x].answer + "', '" + aux.word + "', '" + app.currentGame.categories[ app.currentGame.answers[x].topic ].name + "')", 512*totalboxes) );
					app.writeWordBox('ok', aux.points, app.currentGame.answers[x].letter.latinize(), app.currentGame.answers[x].answer, aux.word, app.currentGame.categories[ app.currentGame.answers[x].topic ].name, totalboxes);
					
					totalPoints += aux.points;
					
					// bonus 5 consecutive corrects
					if (consecutive%5 == 0) {
						totalboxes++;
						//app.currentGame.timers.push ( setTimeout("app.writeWordBox('special','" + consecutive + "','" + app.currentGame.answers[x].letter + "','" + app.currentGame.answers[x].answer + "', '" + app.currentGame.categories[ app.currentGame.answers[x].topic ].name + "')", 512*totalboxes) );
						app.writeWordBox('special', consecutive, app.currentGame.answers[x].letter.latinize(), app.currentGame.answers[x].answer, aux.word, app.currentGame.categories[ app.currentGame.answers[x].topic ].name, totalboxes);
						totalPoints += consecutive;
					}
						
				} else {
					consecutive = 0;
					//app.currentGame.timers.push ( setTimeout("app.writeWordBox('neutral','0','" + app.currentGame.answers[x].letter + "','" + app.currentGame.answers[x].answer + "', '" + aux.word + "', '" + app.currentGame.categories[ app.currentGame.answers[x].topic ].name + "')", 512*totalboxes) );
					app.writeWordBox('neutral', 0, app.currentGame.answers[x].letter.latinize(), app.currentGame.answers[x].answer, aux.word, app.currentGame.categories[ app.currentGame.answers[x].topic ].name, totalboxes);
				}
				
				
			} else {
				skips++;
				consecutive = 0;
				totalPoints--;
				//app.currentGame.timers.push ( setTimeout("app.writeWordBox('bad','-1','" + app.currentGame.answers[x].letter + "','', '', '" + app.currentGame.categories[ app.currentGame.answers[x].topic ].name + "')", 512*totalboxes) );
				app.writeWordBox('bad', -1, app.currentGame.answers[x].letter.latinize(), app.currentGame.answers[x].answer, aux.word, app.currentGame.categories[ app.currentGame.answers[x].topic ].name, totalboxes);
			}
			
			totalboxes++;
		}
		
		// show the total Points
		setTimeout(function() {
			d3.select("#wordboxes")
			  .insert("div", ":first-child")
			  .attr("id", "results-number")
			  .html('<div id="results-number-text"></div><div id="results-number-points">' + totalPoints + '</div>');
			
		}, (2+totalboxes)*512);
		
		// try to save the points online
		/*var uuid = "";
		try { uuid = device.uuid; } catch(e) {}
		d3.json(
			"http://studiokah.com/services/nseconds/?action=save&source=android&points="+totalPoints+"&lang="+app.gameOptions.language+"&uuid="+uuid,
			function(d) {
				
			});*/
			
		if (totalPoints > app.userRecords.user.max) {
			app.userRecords.user.max = totalPoints;
		}
		
		// Update records and save in local storage
		app.saveSettings();
		app.loadOnlineRecords();
	}
};

app.initialize();